@@ -1,4 +1,7 @@
 
+# can't really test these.
+# nocov start
+
 checkAnalogSea <- function(){
   if (!requireNamespace("analogsea", quietly = TRUE)) {
     stop("The analogsea package is not available but is required in order to use the provisioning functions. Please install analogsea.",
@@ -107,7 +110,7 @@ install_nginx <- function(droplet){
 }
 
 install_new_r <- function(droplet){
-  analogsea::droplet_ssh(droplet, c("echo 'deb https://cran.rstudio.com/bin/linux/ubuntu trusty/' >> /etc/apt/sources.list",
+  analogsea::droplet_ssh(droplet, c("echo 'deb https://cran.rstudio.com/bin/linux/ubuntu xenial/' >> /etc/apt/sources.list",
                   "apt-key adv --keyserver keyserver.ubuntu.com --recv-keys E084DAB9"))
   analogsea::debian_apt_get_update(droplet)
   analogsea::debian_install_r(droplet)
@@ -394,3 +397,4 @@ do_remove_forward <- function(droplet){
   analogsea::droplet_ssh(droplet, "systemctl reload nginx")
 }
 
+# nocov end
