@@ -1,7 +1,7 @@
 PlumberResponse <- R6Class(
   "PlumberResponse",
   public = list(
-    initialize = function(serializer=jsonSerializer()){
+    initialize = function(serializer=serializer_json()){
       self$serializer <- serializer
     },
     status = 200L,
@@ -18,18 +18,19 @@ PlumberResponse <- R6Class(
       # httpuv doesn't like empty headers lists, and this is a useful field anyway...
       h$Date <- format(Sys.time(), "%a, %d %b %Y %X %Z", tz="GMT")
 
-      if (is.null(h$`Access-Control-Allow-Origin`)){
-        h$`Access-Control-Allow-Origin` <-  "*" # Be permissive with CORS
-      }
-
       # Due to https://github.com/rstudio/httpuv/issues/49, we need each
       # request to be on a separate TCP stream
       h$Connection = "close"
 
+      body <- self$body
+      if (is.null(body)){
+        body <- ""
+      }
+
       list(
         status = self$status,
         headers = h,
-        body = self$body
+        body = body
       )
     },
     # TODO: support multiple setCookies per response
