@@ -1,5 +1,7 @@
+context("Verb enumeration")
+
 test_that("enumerate returns all on 'use'", {
-  expect_equal(enumerateVerbs("use"), c("GET", "PUT", "POST", "DELETE", "HEAD"))
+  expect_equal(enumerateVerbs("use"), c("GET", "PUT", "POST", "DELETE", "HEAD", "OPTIONS"))
 })
 
 test_that("regular verbs return themselves", {
