@@ -1,10 +1,4 @@
-make_req <- function(verb, path){
-  req <- new.env()
-  req$REQUEST_METHOD <- toupper(verb)
-  req$PATH_INFO <- path
-  req$rook.input <- list(read_lines = function(){ "" })
-  req
-}
+context("Images")
 
 test_that("Images are properly rendered", {
   r <- plumber$new("files/image.R")
